@@ -1,6 +1,6 @@
 package Elastic::Model::View;
 {
-  $Elastic::Model::View::VERSION = '0.16';
+  $Elastic::Model::View::VERSION = '0.17';
 }
 
 use Moose;
@@ -255,25 +255,31 @@ sub _build_search_builder { Elastic::Model::SearchBuilder->new }
 #===================================
 sub queryb {
 #===================================
-    my $self = shift;
-    my @args = @_ > 1 ? {@_} : shift();
-    $self->query( $self->search_builder->query(@args)->{query} );
+    my $self  = shift;
+    my @args  = @_ > 1 ? {@_} : shift();
+    my $query = $self->search_builder->query(@args)
+        or return $self->_clone_self;
+    $self->query( $query->{query} );
 }
 
 #===================================
 sub filterb {
 #===================================
-    my $self = shift;
-    my @args = @_ > 1 ? {@_} : shift();
-    $self->filter( $self->search_builder->filter(@args)->{filter} );
+    my $self   = shift;
+    my @args   = @_ > 1 ? {@_} : shift();
+    my $filter = $self->search_builder->filter(@args)
+        or return $self->_clone_self;
+    $self->filter( $filter->{filter} );
 }
 
 #===================================
 sub post_filterb {
 #===================================
-    my $self = shift;
-    my @args = @_ > 1 ? {@_} : shift();
-    $self->post_filter( $self->search_builder->filter(@args)->{filter} );
+    my $self   = shift;
+    my @args   = @_ > 1 ? {@_} : shift();
+    my $filter = $self->search_builder->filter(@args)
+        or return $self->_clone_self;
+    $self->post_filter( $filter->{filter} );
 }
 
 #===================================
@@ -342,6 +348,13 @@ sub _clone_args {
     $self->$orig();
 }
 
+#===================================
+sub _clone_self {
+#===================================
+    my $self = shift;
+    return bless {%$self}, ref $self;
+}
+
 #===================================
 sub _check_no_fields {
 #===================================
@@ -519,7 +532,7 @@ Elastic::Model::View - Views to query your docs in ElasticSearch
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
